==> kapptemplate-14.12.2.tar.xz: kapptemplate-14.12.2/src/application/apptemplateitem.h <==
/***************************************************************************
 *   Copyright 2007 Alexander Dymo <adymo@kdevelop.org>                    *
 *   Copyright 2008 Anne-Marie Mahfouf <annma@kde.org>                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef APPTEMPLATEITEM_H
#define APPTEMPLATEITEM_H

#include <QStandardItem>

class AppTemplateItem: public QStandardItem
{
public:
    AppTemplateItem();
    AppTemplateItem(const QString &text);
    AppTemplateItem(const QIcon &icon, const QString &text);
    explicit AppTemplateItem(int rows, int columns = 1);

private:
    void init();
};

#endif // APPTEMPLATEITEM_H

==> kapptemplate_19.04.3.orig.tar.xz: kapptemplate-19.04.3/src/application/apptemplateitem.h <==
/***************************************************************************
 *   Copyright 2007 Alexander Dymo <adymo@kdevelop.org>                    *
 *   Copyright 2008 Anne-Marie Mahfouf <annma@kde.org>                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef APPTEMPLATEITEM_H
#define APPTEMPLATEITEM_H

#include <QStandardItem>

class AppTemplateItem: public QStandardItem
{
public:
    AppTemplateItem();
    explicit AppTemplateItem(const QString &text);
    AppTemplateItem(const QIcon &icon, const QString &text);
    explicit AppTemplateItem(int rows, int columns = 1);

private:
    void init();
};

#endif // APPTEMPLATEITEM_H
